Rdocumentation
powered by
Learn R Programming
popgraph (version 1.0)
congruence_topology: Returns congruence topology
Description
Takes two graphs and returns topology that is the intersection of the edge sets.
Usage
congruence_topology(graph1, graph2, warn.nonoverlap = TRUE)
Arguments
graph1
An object of type
population_graph
graph2
An object of type
population_graph
warn.nonoverlap
A flag indicating that a warning should be thrown if the node sets are not equal (default = TRUE )
Value
An object of type
population_graph
where the node and edge sets are the intersection of the two.